@@ -1,4 +1,4 @@
-### discretize.R  (2013-06-21)
+### discretize.R  (2013-07-15)
 ###
 ###    Discretize a continuous random variable
 ###
@@ -25,8 +25,21 @@
 discretize = function( x, numBins, r=range(x) )
 {
   b = seq(from=r[1], to=r[2], length.out=numBins+1 )
-  y = table( cut(x, breaks=b ) )
+  y = table( cut(x, breaks=b , include.lowest=TRUE) )
 
   return( y )
 }
 
+discretize2d = function( x1, x2, numBins1, numBins2, r1=range(x1), r2=range(x2) )
+{
+  b1 = seq(from=r1[1], to=r1[2], length.out=numBins1+1 )
+  b2 = seq(from=r2[1], to=r2[2], length.out=numBins2+1 )
+
+  y2d = table( cut(x1, breaks=b1, include.lowest=TRUE ), 
+               cut(x2, breaks=b2, include.lowest=TRUE ) )
+
+  return( y2d )
+}
+
+
+
