@@ -1,8 +1,9 @@
-### entropy.empirical.R  (2008-09-28)
+### entropy.empirical.R  (2013-07-16)
 ###
-###    Empirical entropy and mutual information estimator
+###    Empirical estimators of entropy, mutual information and related
+###    quantities.
 ###
-### Copyright 2008 Korbinian Strimmer
+### Copyright 2008-13 Korbinian Strimmer
 ###
 ###
 ### This file is part of the `entropy' library for R and related languages.
@@ -35,9 +36,30 @@ freqs.empirical = function(y)
   return( y/sum(y) )
 }
 
+
 # empirical mutual information
-mi.empirical = function(y, unit=c("log", "log2", "log10"))
+mi.empirical = function(y2d, unit=c("log", "log2", "log10"))
 {
-  return( mi.plugin(freqs.empirical(y), unit=unit) )
+  return( mi.plugin(freqs.empirical(y2d), unit=unit) )
 }
 
+# empirical chi-squared of independence
+chi2indep.empirical = function(y2d, unit=c("log", "log2", "log10"))
+{
+  return( chi2indep.plugin(freqs.empirical(y2d), unit=unit) )
+}
+
+
+# empirical chi-squared statistic
+chi2.empirical = function(y1, y2, unit=c("log", "log2", "log10"))
+{
+  return( chi2.plugin(freqs.empirical(y1), freqs.empirical(y2), unit=unit) )
+}
+
+# empirical KL divergence
+KL.empirical = function(y1, y2, unit=c("log", "log2", "log10"))
+{
+  return( KL.plugin(freqs.empirical(y1), freqs.empirical(y2), unit=unit) )
+}
+
+
