@@ -1,8 +1,9 @@
-### mi.plugin.R  (2008-09-28)
+### mi.plugin.R  (2013-07-16)
 ###
-###    Plug-in mutual information estimator
+###    Plug-in estimator of mutual information and 
+###    of the chi-squared statistic of independence
 ###
-### Copyright 2008 Korbinian Strimmer
+### Copyright 2008-13 Korbinian Strimmer
 ###
 ###
 ### This file is part of the `entropy' library for R and related languages.
@@ -22,21 +23,36 @@
 ### MA 02111-1307, USA
 
 
+
 mi.plugin = function(freqs2d, unit=c("log", "log2", "log10"))
 {
   unit = match.arg(unit)
 
   freqs2d = as.matrix(freqs2d/sum(freqs2d)) # just to make sure ...
 
-  freqs.x = apply(freqs2d, 1, sum) # marginal frequencies
-  freqs.y = apply(freqs2d, 2, sum)
-
-  H.xy = entropy.plugin(freqs2d, unit=unit)
-  H.x = entropy.plugin(freqs.x, unit=unit)
-  H.y = entropy.plugin(freqs.y, unit=unit)
-  
-  MI = H.x + H.y - H.xy
+  freqs.x = rowSums(freqs2d) # marginal frequencies
+  freqs.y = colSums(freqs2d)
+  freqs.null = freqs.x %o% freqs.y # independence null model
 
+  MI = KL.plugin(freqs2d, freqs.null, unit=unit)
+ 
   return(MI)
 }
 
+
+chi2indep.plugin = function(freqs2d, unit=c("log", "log2", "log10"))
+{
+  unit = match.arg(unit)
+
+  freqs2d = as.matrix(freqs2d/sum(freqs2d)) # just to make sure ...
+
+  freqs.x = rowSums(freqs2d) # marginal frequencies
+  freqs.y = colSums(freqs2d)
+  freqs.null = freqs.x %o% freqs.y # independence null model
+
+  chi2 = chi2.plugin(freqs2d, freqs.null, unit=unit)
+ 
+  return(chi2)
+}
+
+
